┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphincontroller.h
diff options
context:
space:
mode:
authorPeter Penz <[email protected]>2009-02-11 20:45:12 +0000
committerPeter Penz <[email protected]>2009-02-11 20:45:12 +0000
commit2f47863c68bb0ac0417eed76f713ced651a4908a (patch)
tree4deffd5657f8f39c02623d9a873e894b3a9ec8c0 /src/dolphincontroller.h
parent5cec8a2dd95d6ccbc0d425c449df70cd645e3d29 (diff)
- allow the view implementations to attach custom actions to the context menu
- let the "details view" show the "[x] Expandable Folders" action in the context menu CCMAIL: [email protected] svn path=/trunk/KDE/kdebase/apps/; revision=924867
Diffstat (limited to 'src/dolphincontroller.h')
-rw-r--r--src/dolphincontroller.h18
1 files changed, 11 insertions, 7 deletions
diff --git a/src/dolphincontroller.h b/src/dolphincontroller.h
index eb5ef9ce7..29dd7dfb1 100644
--- a/src/dolphincontroller.h
+++ b/src/dolphincontroller.h
@@ -121,9 +121,11 @@ public:
* should be invoked by the view implementation when a context
* menu should be opened. The abstract Dolphin view itself
* takes care itself to get the selected items depending from
- * \a pos.
+ * \a pos. It is possible to define a custom list of actions for
+ * the context menu by \a customActions.
*/
- void triggerContextMenuRequest(const QPoint& pos);
+ void triggerContextMenuRequest(const QPoint& pos,
+ const QList<QAction*>& customActions = QList<QAction*>());
/**
* Requests an activation of the view and emits the signal
@@ -272,12 +274,14 @@ signals:
/**
* Is emitted if a context menu should be opened (see triggerContextMenuRequest()).
* The abstract Dolphin view connects to this signal and will open the context menu.
* @param pos Position relative to the view widget where the
* context menu should be opened. It is recommended
* to get the corresponding model index from
* this position.
*/
- void requestContextMenu(const QPoint& pos);
+ void requestContextMenu(const QPoint& pos, QList<QAction*> customActions);
/**
* Is emitted if the view has been activated by e. g. a mouse click.
@@ -272,12 +274,14 @@ signals:
* Is emitted if a context menu should be opened (see triggerContextMenuRequest()).
* The abstract Dolphin view connects to this signal and will open the context menu.
- * @param pos Position relative to the view widget where the
- * context menu should be opened. It is recommended
- * to get the corresponding model index from
- * this position.
+ * @param pos Position relative to the view widget where the
+ * context menu should be opened. It is recommended
+ * to get the corresponding model index from
+ * this position.
+ * @param customActions List of actions that is added to the context menu when
+ * the menu is opened above the viewport.
*/